class OrdersController < ApplicationController

  before_filter :authorize

  def index
    if current_user.user_type_id == 1
      @orders = Order.where("user_id == #{current_user.id} and status > 1")
    else
      @orders = Order.where("status > 1")
    end
  end

  def new
    @order = Order.new
    @shops = Shop.all
    @users = User.all
    @payment_types = PaymentType.all
    @order_products = @order.order_products.build
  end

  def destroy
    @order = Order.find(params[:id])
    @order.destroy
    message = "Order deleted successfully"
    flash[:success] = message
    redirect_to orders_path
  end

  def show
    @order = Order.find(params[:id])
  end

  def edit
    @order = Order.find(params[:id])

    if current_user.user_type.id == 1
      @order.address = current_user.address
      @order.city = current_user.city
      @order.region = current_user.region
      @order.postcode = current_user.postcode
    end

    @shops = Shop.all
    @users = User.all
    @payment_types = PaymentType.all
  end

  def create
    @order = Order.new(order_params)
    @shops = Shop.all
    @users = User.all
    @payment_types = PaymentType.all

    if @order.save
      redirect_to new_payment_path
    else
      flash[:danger] = "Unable to create"
      render 'new'
    end
  end

  def update
    @order = Order.find(params[:id])
    @shops = Shop.all
    @users = User.all
    @payment_types = PaymentType.all

    # check if it's not empty
    if @order.order_products.count == 0
      flash[:danger] = "Empty order. Please add products to the cart first."
      render 'edit'
    elsif @order.update(order_params)
      if is_user_employee?
        message = "Order updated successfully"
        flash[:success] = message

        # sent shipped email to the customer
        if @order.status == "shipped" || @order.status == "ready"
          OrderNotifier.shipped(@order).deliver_now
        end

        redirect_to order_path(@order)
      else
        redirect_to new_payment_path
      end
    else
      flash[:danger] = "Unable to update"
      render 'edit'
    end
  end

  private
  def order_params
    params.require(:order).permit(:shop_id, :user_id, :status, :payment_type_id, :telephone, :address, :city, :region, :postcode, {order_products_attributes: [:id, :product_id, :quantity, :price, :_destroy]})
  end
end
