class PaymentsController < ApplicationController
  before_action :set_payment, only: [:show, :edit, :update, :destroy]

  # GET /payments
  # GET /payments.json
  def index
    @payments = Payment.all
  end

  # GET /payments/1
  # GET /payments/1.json
  def show
  end

  # GET /payments/new
  def new
    @payment = Payment.new
    @order = Order.find(session[:order_id])
    user = User.find(@order.user_id)
    @payment.update_attributes(
      order_id: @order.id,
      amount: OrderProduct.where(order_id: @order.id).map { |o| o[:price] * o[:quantity] }.sum,
      cardholder: "#{user.name} #{user.surname}",
    )
  end

  # GET /payments/1/edit
  def edit
    @payment = Payment.find(params[:id])
    @order = Order.find(@payment.order_id)
  end

  # PATCH/PUT /payments/1
  def update
    sleep(4)
    @order = Order.find(@payment.order_id)
    if @payment.update(payment_params)

      @order.update_attributes(status: 2)
      message = "Order updated successfully"
      flash[:success] = message

      # creates a new order
      new_order = Order.create
      session[:order_id] = new_order.id

      @order = Order.find(@payment.order_id)
      redirect_to @order
    else
      render :edit
    end
  end

  # PATCH/PUT /payments/1
  def create
    sleep(4)
    @order = Order.find(session[:order_id])

    # cash / payment when collect order
    message = "<b>Your order was successfully submitted!</b><br><br>" \
                "Thank you for shopping at Take Away App, you will receive a confirmation e-mail shortly.<br><br>" \
                "Please, find the details below and if you prefer, you can start another order " \
                "<b><a href='/menu'>here</a></b>."
    if @order.payment_type_id == 2
      @order.update_attributes(status: 2)
      flash[:success] = message
      # send email
      OrderNotifier.received(@order).deliver_now
      # creates a new order
      new_order = Order.create
      session[:order_id] = new_order.id
      @order = Order.find(payment_params["order_id"])
      redirect_to @order
    else
      @payment = Payment.new(payment_params)
      if @payment.save(payment_params)
        @order.update_attributes(status: 2)
        flash[:success] = message

        # Send emails
        #   > order email
        OrderNotifier.received(@order).deliver_now
        #   > payment email (if card)
        if @order.payment_type_id = 1
          PaymentNotifier.paid(@order, @payment).deliver_now
        end

        # creates a new order
        new_order = Order.create
        session[:order_id] = new_order.id
        @order = Order.find(@payment.order_id)
        redirect_to @order
      else
        render :new
      end
    end
  end

  # DELETE /payments/1
  # DELETE /payments/1.json
  def destroy
    @payment.destroy
    respond_to do |format|
      format.html { redirect_to payments_url, notice: 'Payment was successfully destroyed.' }
      format.json { head :no_content }
    end
  end

  private
    # Use callbacks to share common setup or constraints between actions.
    def set_payment
      @payment = Payment.find(params[:id])
    end

    # Never trust parameters from the scary internet, only allow the white list through.
    def payment_params
      params.require(:payment).permit(:amount, :order_id, :cardholder, :card_number, :card_expiration_month, :card_expiration_year, :card_security_code)
    end
end
