class ProductsController < ApplicationController

  before_filter :authorize

  def index
    @products = Product.all
  end

  def show
    @product = Product.find(params[:id])
    @categories = @product.categories
    @formats = @product.formats
    respond_to do |format|
      format.html # show.html.erb
      format.json { render json: @product }
    end
  end

  def new
    @product = Product.new
    @categories = Category.all
    @formats = Format.all
  end

  def destroy
    @product = Product.find(params[:id])
    @product.destroy
    message = "Product deleted successfully"
    flash[:success] = message
    redirect_to products_path
  end

  def edit
  	@product = Product.find(params[:id])
    @categories = Category.all
    @formats = Format.all
  end

  def create
    @product = Product.new(product_params)
    @categories = Category.all
    @formats = Format.all
    if @product.save
      message = "Product created successfully"
      flash[:success] = message
      redirect_to @product
    else
      render 'new'
    end
  end

  def update
    @product = Product.find(params[:id])
    @categories = Category.all
    @formats = Format.all
    if @product.update(product_params)
      message = "Product updated successfully"
      flash[:success] = message
      redirect_to @product
    else
      flash[:danger] = "Unable to update"
      render 'edit'
    end
  end

  private
  def product_params
    params.require(:product).permit(:name, :photo, :price, :description, {:category_ids => []}, {:format_ids => []}, :status)
  end
end
