class UsersController < ApplicationController

  def index
    @users = User.all
  end

  def show
    @user = User.find(params[:id])
  end

  def new
    if params[:new_user]
      message = "You need to be registered to order."
      flash[:success] = message
    end
    @user = User.new
    @user_types = UserType.all
  end

  def destroy
    @user = User.find(params[:id])
    @user.destroy
    message = "User deleted successfully"
    flash[:success] = message
    redirect_to users_path
  end

  def edit
    @user = User.find(params[:id])
    @user_types = UserType.all
  end

  def create
    @user = User.new(user_params)
    if @user.save
      if current_user.present? && current_user.user_type_id > 1
        message = "User created successfully"
        flash[:success] = message
        redirect_to @user
      else

        # reset order
        new_order = Order.create
        session[:order_id] = new_order.id

        @user.authenticate(params[:password])
        session[:user_id] = @user.id
        message = "Welcome #{@user.name} !"
        UserNotifier.registered(@user).deliver_now
        flash[:success] = message
        redirect_to root_path
      end
    else
      flash[:danger] = "Unable to create a new user"
      render 'new'
    end
  end

  def update
    @user = User.find(params[:id])
    if @user.update(user_params)
      if current_user.present? && current_user.user_type_id > 1
        message = "User updated successfully"
        flash[:success] = message
        redirect_to @user
      else
        message = "Settings updated successfully"
        flash[:success] = message
        redirect_to root_path
      end
    else
      flash[:danger] = "Unable to update user settings"
      render 'edit'
    end
  end

  private
  def user_params
    params.require(:user).permit(:name, :surname, :email, :address, :city, :region, :postcode,
                                 :password, :password_confirmation, :user_type_id)
  end
end
