class Order < ActiveRecord::Base
  belongs_to :shop
  belongs_to :user
  belongs_to :payment_type
  has_one :payment

  has_many :order_products
  has_many :products, :through => :order_products

  accepts_nested_attributes_for :order_products

  # delegate :empty?, to: :order_products

  enum status: %w(shoping draft received preparation bake quality ready shipped)

  def inline
    created_at.to_s(:db) + " - " + user.full_name + " (" + status + ")"
  end

  def total_price
    total = 0
    order_products.each { |product| total += product.quantity * product.price }
    total
  end

  def self.get_active_months
    months = []
    Order.where("status > 1").each do |order|
      str = order.created_at.to_s.slice(0..6)
      months.include?(str) ? nil : months << str
    end
    months
  end

  def self.get_active_years
    years = []
    Order.where("status > 1").each do |order|
      str = order.created_at.to_s.slice(0..3)
      years.include?(str) ? nil : years << str
    end
    years
  end

  def self.calc(order_id)
    if order_id.present?
      order = Order.find(order_id)
      order.order_products.count
    else 0 end
  end

  def self.calc_num_product(order_id, product_id)
    if order_id.present?
      order = Order.find(order_id)
      product = order.order_products.where(product_id: product_id).first
      product.present? ? product.quantity : 0
    else 0 end
  end
end
